/* Generated automatically. */
static const char configuration_arguments[] = "/usr/obj/ports/xtensa-lx106-elf-gcc-10.2.0/gcc-10.2.0/configure --with-as=/usr/local/xtensa-lx106-elf/bin/xtensa-lx106-elf-as --with-ld=/usr/local/xtensa-lx106-elf/bin/xtensa-lx106-elf-ld --with-sysroot=/usr/local/xtensa-lx106-elf/xtensa-lx106-elf --with-gmp=/usr/local --with-isl=/usr/local --disable-multilib --target=xtensa-lx106-elf --prefix=/usr/local/xtensa-lx106-elf --disable-shared --with-newlib --enable-threads=no --disable-__cxa_atexit --disable-libgomp --disable-libmudflap --disable-nls --disable-bootstrap --enable-languages=c,c++ --disable-lto --disable-libstdcxx-verbose --enable-static=yes";
static const char thread_model[] = "single";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { NULL, NULL} };
